@@ -5,14 +5,15 @@ from TrainingDataCreation import create_training_data as createData
 from custom_t5_model import CustomT5
 from sklearn.model_selection import train_test_split
 import os
+
 use_gpu = False
-model_path = f"outputs/trained-epoch-2-train-loss-0.1147-val-loss-0.0633"
+model_path = f"outputs/trained-epoch-4-train-loss-0.0029-val-loss-0.0037"
 path = f"datasets/generated_training.csv"
 
 
-def trainModel(df,use_gpu=False):
+def trainModel(df, use_gpu=False):
     model = CustomT5()
-    
+
     df.dropna()
 
     df = df.rename(columns={"UseCase": "target_text", "Sentences": "source_text"})
@@ -34,7 +35,7 @@ def trainModel(df,use_gpu=False):
                 batch_size=8, max_epochs=5, use_gpu=use_gpu)
 
 
-def loadModel(sentences,use_gpu=False):
+def loadModel(sentences, use_gpu=False):
     model = CustomT5()
     # let's load the trained model for inferencing:
     model.load_model("t5", model_path, use_gpu=use_gpu)
@@ -42,6 +43,10 @@ def loadModel(sentences,use_gpu=False):
 
 
 def testAccuracy():
+    try:
+        os.mkdir("report")
+    except OSError as error:
+        pass
     unseen_df = pd.read_csv(r"datasets/unseen_data.csv")
     report = pd.DataFrame(data={"sentence": [None], "Predicted": [None], "Expected": [None], "Result": [None]})
     for ind in unseen_df.index:
@@ -57,11 +62,8 @@ def testAccuracy():
                 data={"sentence": [sentence], "Predicted": [use_case], "Expected": [target], "Result": ["Pass"]})
         if len(report.dropna()) == 0:
             report = df1
-        report = report.append(df1, ignore_index=True)
-    try:
-        os.mkdir("report")
-    except OSError as error:
-        pass
+        report = pd.concat([report, df1])
+        print(ind, "out of", len(unseen_df),": ", sentence, target, df1["Result"][0])
     report.to_csv("report/report.csv", mode='w', index=False)
 
 
@@ -89,9 +91,8 @@ if __name__ == '__main__':
     controller(val=3) 
     Have to change trained model path.
     """
-    sentence = "Expiration Date must be of type date"
-    # controller(sentence=sentence)
-    controller(1)
-    controller(2)
-
-
+    sentence = "duepwj lies between one thousand, eight hundred and fifty-eight and sixty thousand, four hundred and eighty-two"
+    controller(sentence=sentence)
+    # controller(1)
+    # controller(2)
+    # controller(3)
