@@ -1,17 +1,19 @@
-from flask import Flask, request, render_template
+from flask import Flask
 
 import main
-from flask_cors import CORS
+import pandas as pd
+
 app = Flask(__name__)
-# CORS(app)
+
+
 
 
 @app.route('/<string:sentences>/')
 def getSentences(sentences):
-    return main.loadModel(sentences)
+    return main.loadModel(sentences,True)
 
 
-@app.route('/', methods=["GET", "POST"])
+# @app.route('/', methods=["GET", "POST"])
 #
 # def gfg():
 #     if request.method == "POST":
@@ -21,10 +23,11 @@ def getSentences(sentences):
 #        return responses
 #     return render_template("form.html")
 
-
 @app.route('/train/')
 def train():
-    main.trainModel()
+    main.controller(1)
+    df = pd.read_csv(main.path)
+    main.trainModel(df,True)
 
 
 app.debug = False
